@@ -1,3 +1,4 @@
+from ._base import Graphic
 from .line import LineGraphic
 from .scatter import ScatterGraphic
 from .image import ImageGraphic
@@ -6,9 +7,10 @@ from .line_collection import LineCollection, LineStack
 
 
 __all__ = [
+    "Graphic",
     "LineGraphic",
-    "ImageGraphic",
     "ScatterGraphic",
+    "ImageGraphic",
     "TextGraphic",
     "LineCollection",
     "LineStack",
