@@ -6,21 +6,35 @@ import pygfx
 
 from ._positions_base import PositionsGraphic
 from .selectors import LinearRegionSelector, LinearSelector, RectangleSelector
-from ._features import Thickness, SizeSpace
+from .features import (
+    Thickness,
+    VertexPositions,
+    VertexColors,
+    UniformColor,
+    VertexCmap,
+    SizeSpace,
+)
+from ..utils import quick_min_max
 
 
 class LineGraphic(PositionsGraphic):
-    _features = {"data", "colors", "cmap", "thickness", "size_space"}
+    _features = {
+        "data": VertexPositions,
+        "colors": (VertexColors, UniformColor),
+        "cmap": (VertexCmap, None),  # none if UniformColor
+        "thickness": Thickness,
+        "size_space": SizeSpace,
+    }
 
     def __init__(
         self,
         data: Any,
         thickness: float = 2.0,
-        colors: str | np.ndarray | Iterable = "w",
+        colors: str | np.ndarray | Sequence = "w",
         uniform_color: bool = False,
         alpha: float = 1.0,
         cmap: str = None,
-        cmap_transform: np.ndarray | Iterable = None,
+        cmap_transform: np.ndarray | Sequence = None,
         isolated_buffer: bool = True,
         size_space: str = "screen",
         **kwargs,
@@ -31,14 +45,17 @@ class LineGraphic(PositionsGraphic):
         Parameters
         ----------
         data: array-like
-            Line data to plot, 2D must be of shape [n_points, 2], 3D must be of shape [n_points, 3]
+            Line data to plot. Can provide 1D, 2D, or a 3D data.
+            | If passing a 1D array, it is used to set the y-values and the x-values are generated as an integer range
+            from [0, data.size]
+            | 2D data must be of shape [n_points, 2]. 3D data must be of shape [n_points, 3]
 
         thickness: float, optional, default 2.0
             thickness of the line
 
         colors: str, array, or iterable, default "w"
             specify colors as a single human-readable string, a single RGBA array,
-            or an iterable of strings or RGBA arrays
+            or a Sequence (array, tuple, or list) of strings or RGBA arrays
 
         uniform_color: bool, default ``False``
             if True, uses a uniform buffer for the line color,
@@ -48,17 +65,18 @@ class LineGraphic(PositionsGraphic):
             alpha value for the colors
 
         cmap: str, optional
-            apply a colormap to the line instead of assigning colors manually, this
-            overrides any argument passed to "colors"
+            Apply a colormap to the line instead of assigning colors manually, this
+            overrides any argument passed to "colors". For supported colormaps see the
+            ``cmap`` library catalogue: https://cmap-docs.readthedocs.io/en/stable/catalog/
 
         cmap_transform: 1D array-like of numerical values, optional
             if provided, these values are used to map the colors from the cmap
 
         size_space: str, default "screen"
-            coordinate space in which the size is expressed (‘screen’, ‘world’, ‘model’)
+            coordinate space in which the thickness is expressed ("screen", "world", "model")
 
         **kwargs
-            passed to Graphic
+            passed to :class:`.Graphic`
 
         """
 
@@ -107,7 +125,7 @@ class LineGraphic(PositionsGraphic):
 
     @property
     def thickness(self) -> float:
-        """line thickness"""
+        """Get or set the line thickness"""
         return self._thickness.value
 
     @thickness.setter
@@ -115,24 +133,22 @@ class LineGraphic(PositionsGraphic):
         self._thickness.set_value(self, value)
 
     def add_linear_selector(
-        self, selection: float = None, padding: float = 0.0, axis: str = "x", **kwargs
+        self, selection: float = None, axis: str = "x", **kwargs
     ) -> LinearSelector:
         """
-        Adds a linear selector.
+        Adds a :class:`.LinearSelector`.
+
+        Selectors are just ``Graphic`` objects, so you can manage, remove, or delete them from a
+        plot area just like any other ``Graphic``.
 
-        Parameters
-        ----------
         Parameters
         ----------
         selection: float, optional
-            selected point on the linear selector, computed from data if not provided
+            selected point on the linear selector, by default the first datapoint on the line.
 
         axis: str, default "x"
             axis that the selector resides on
 
-        padding: float, default 0.0
-            Extra padding to extend the linear selector along the orthogonal axis to make it easier to interact with.
-
         kwargs
             passed to :class:`.LinearSelector`
 
@@ -143,7 +159,7 @@ class LineGraphic(PositionsGraphic):
         """
 
         bounds_init, limits, size, center = self._get_linear_selector_init_args(
-            axis, padding
+            axis, padding=0
         )
 
         if selection is None:
@@ -152,8 +168,6 @@ class LineGraphic(PositionsGraphic):
         selector = LinearSelector(
             selection=selection,
             limits=limits,
-            size=size,
-            center=center,
             axis=axis,
             parent=self,
             **kwargs,
@@ -174,8 +188,10 @@ class LineGraphic(PositionsGraphic):
         **kwargs,
     ) -> LinearRegionSelector:
         """
-        Add a :class:`.LinearRegionSelector`. Selectors are just ``Graphic`` objects, so you can manage,
-        remove, or delete them from a plot area just like any other ``Graphic``.
+        Add a :class:`.LinearRegionSelector`.
+
+        Selectors are just ``Graphic`` objects, so you can manage, remove, or delete them from a
+        plot area just like any other ``Graphic``.
 
         Parameters
         ----------
@@ -231,8 +247,10 @@ class LineGraphic(PositionsGraphic):
         **kwargs,
     ) -> RectangleSelector:
         """
-        Add a :class:`.RectangleSelector`. Selectors are just ``Graphic`` objects, so you can manage,
-        remove, or delete them from a plot area just like any other ``Graphic``.
+        Add a :class:`.RectangleSelector`.
+
+        Selectors are just ``Graphic`` objects, so you can manage, remove, or delete them from a
+        plot area just like any other ``Graphic``.
 
         Parameters
         ----------
@@ -298,6 +316,6 @@ class LineGraphic(PositionsGraphic):
         size = int(np.ptp(magn_vals) * 1.5 + padding)
 
         # center of selector along the other axis
-        center = np.nanmean(magn_vals)
+        center = sum(quick_min_max(magn_vals)) / 2
 
         return bounds_init, limits, size, center
