@@ -16,12 +16,17 @@ class MoveInfo:
     stores move info for a WorldObject
     """
 
-    # last position for an edge, fill, or vertex in world coordinates
-    # can be None, such as key events
-    last_position: Union[np.ndarray, None]
+    # The initial selection. Differs per type of selector
+    start_selection: Any
+
+    # The initial world position of the cursor
+    start_position: np.ndarray | None
+
+    # Delta position in world coordinates
+    delta: np.ndarray
 
     # WorldObject or "key" event
-    source: Union[WorldObject, str]
+    source: WorldObject | str
 
 
 # key bindings used to move the selector
@@ -35,8 +40,6 @@ key_bind_direction = {
 
 # Selector base class
 class BaseSelector(Graphic):
-    _features = {"selection"}
-
     @property
     def axis(self) -> str:
         return self._axis
@@ -138,16 +141,18 @@ class BaseSelector(Graphic):
 
         self._hover_responsive: Tuple[WorldObject, ...] = hover_responsive
 
+        # Original color of object that we change the colors of
+        self._original_colors = {}
+
+        # Colors as they are changed by the hover events, so they can be restored after a move action
+        self._hover_colors = {}
+
         if hover_responsive is not None:
-            self._original_colors = dict()
             for wo in self._hover_responsive:
                 self._original_colors[wo] = wo.material.color
 
         self._axis = axis
 
-        # current delta in world coordinates
-        self.delta: np.ndarray = None
-
         self.arrow_keys_modifier = arrow_keys_modifier
         # if not False, moves the slider on every render cycle
         self._key_move_value = False
@@ -275,9 +280,14 @@ class BaseSelector(Graphic):
             pygfx ``Event``
 
         """
-        last_position = self._plot_area.map_screen_to_world(ev)
+        position = self._plot_area.map_screen_to_world(ev)
 
-        self._move_info = MoveInfo(last_position=last_position, source=event_source)
+        self._move_info = MoveInfo(
+            start_selection=None,
+            start_position=position,
+            delta=np.zeros_like(position),
+            source=event_source,
+        )
         self._moving = True
 
         self._initial_controller_state = self._plot_area.controller.enabled
@@ -300,33 +310,31 @@ class BaseSelector(Graphic):
         # disable controller during moves
         self._plot_area.controller.enabled = False
 
-        # get pointer current world position
-        world_pos = self._plot_area.map_screen_to_world(ev)
+        # get pointer current world position, in 'mouse capute mode'
+        world_pos = self._plot_area.map_screen_to_world(ev, allow_outside=True)
 
-        # outside this viewport
-        if world_pos is None:
-            return
-
-        # compute the delta
-        self.delta = world_pos - self._move_info.last_position
+        # update the delta
+        self._move_info.delta = world_pos - self._move_info.start_position
         self._pygfx_event = ev
 
-        self._move_graphic(self.delta)
-
-        # update last position
-        self._move_info.last_position = world_pos
+        self._move_graphic(self._move_info)
 
         # restore the initial controller state
         # if it was disabled, keep it disabled
         self._plot_area.controller.enabled = self._initial_controller_state
 
-    def _move_graphic(self, delta: np.ndarray):
+    def _move_graphic(self, move_info: MoveInfo):
         raise NotImplementedError("Must be implemented in subclass")
 
     def _move_end(self, ev):
         self._move_info = None
         self._moving = False
 
+        # Reset hover state
+        for wo, color in self._hover_colors.items():
+            wo.material.color = color
+        self._hover_colors.clear()
+
         # restore the initial controller state
         # if it was disabled, keep it disabled
         if self._initial_controller_state is not None:
@@ -362,24 +370,30 @@ class BaseSelector(Graphic):
         if world_pos is None:
             return
 
-        self.delta = world_pos - current_pos_world
+        delta = world_pos - current_pos_world
         self._pygfx_event = ev
 
         # use fill by default as the source, such as in region selectors
         if len(self._fill) > 0:
-            self._move_info = MoveInfo(
-                last_position=current_pos_world, source=self._fill[0]
+            move_info = MoveInfo(
+                start_selection=None,
+                start_position=None,
+                delta=delta,
+                source=self._fill[0],
             )
         # else use an edge, such as for linear selector
         else:
-            self._move_info = MoveInfo(
-                last_position=current_pos_world, source=self._edges[0]
+            move_info = MoveInfo(
+                start_position=None,
+                start_selection=None,
+                delta=delta,
+                source=self._edges[0],
             )
 
-        self._move_graphic(self.delta)
-        self._move_info = None
+        self._move_graphic(move_info)
 
     def _pointer_enter(self, ev):
+
         if self._hover_responsive is None:
             return
 
@@ -390,17 +404,23 @@ class BaseSelector(Graphic):
         if wo in self._edges:
             self._edge_hovered = True
 
-        wo.material.color = "magenta"
+        if self._moving:
+            self._hover_colors[wo] = "magenta"
+        else:
+            wo.material.color = "magenta"
 
     def _pointer_leave(self, ev):
         if self._hover_responsive is None:
             return
 
+        self._edge_hovered = False
+
         # reset colors
         for wo in self._hover_responsive:
-            wo.material.color = self._original_colors[wo]
-
-        self._edge_hovered = False
+            if self._moving:
+                self._hover_colors[wo] = self._original_colors[wo]
+            else:
+                wo.material.color = self._original_colors[wo]
 
     def _toggle_arrow_key_moveable(self, ev):
         self.arrow_key_events_enabled = not self.arrow_key_events_enabled
@@ -413,15 +433,23 @@ class BaseSelector(Graphic):
             # set event source
             # use fill by default as the source
             if len(self._fill) > 0:
-                self._move_info = MoveInfo(last_position=None, source=self._fill[0])
+                move_info = MoveInfo(
+                    start_selection=None,
+                    start_position=None,
+                    delta=delta,
+                    source=self._fill[0],
+                )
             # else use an edge
             else:
-                self._move_info = MoveInfo(last_position=None, source=self._edges[0])
+                move_info = MoveInfo(
+                    start_selection=None,
+                    start_position=None,
+                    delta=delta,
+                    source=self._edges[0],
+                )
 
             # move the graphic
-            self._move_graphic(delta=delta)
-
-            self._move_info = None
+            self._move_graphic(move_info)
 
     def _key_down(self, ev):
         # key bind modifier must be set and must be used for the event
@@ -443,8 +471,6 @@ class BaseSelector(Graphic):
         if ev.key in key_bind_direction.keys():
             self._key_move_value = False
 
-        self._move_info = None
-
     def _fpl_prepare_del(self):
         if hasattr(self, "_pfunc_fill"):
             self._plot_area.renderer.remove_event_handler(
