@@ -11,6 +11,7 @@ from rendercanvas import BaseRenderCanvas
 from ._utils import create_controller
 from ..graphics._base import Graphic
 from ..graphics.selectors._base_selector import BaseSelector
+from ._graphic_methods_mixin import GraphicMethodsMixin
 from ..legends import Legend
 
 
@@ -24,11 +25,10 @@ else:
     IPYTHON = get_ipython()
 
 
-class PlotArea:
+class PlotArea(GraphicMethodsMixin):
     def __init__(
         self,
         parent: Union["PlotArea", "Figure"],
-        position: tuple[int, int] | str,
         camera: pygfx.PerspectiveCamera,
         controller: pygfx.Controller,
         scene: pygfx.Scene,
@@ -70,7 +70,6 @@ class PlotArea:
         """
 
         self._parent = parent
-        self._position = position
 
         self._scene = scene
         self._canvas = canvas
@@ -88,14 +87,10 @@ class PlotArea:
         self._animate_funcs_pre: list[callable] = list()
         self._animate_funcs_post: list[callable] = list()
 
-        self.renderer.add_event_handler(self.set_viewport_rect, "resize")
-
-        # list of hex id strings for all graphics managed by this PlotArea
-        # the real Graphic instances are managed by REFERENCES
+        # list of all graphics managed by this PlotArea
         self._graphics: list[Graphic] = list()
 
         # selectors are in their own list so they can be excluded from scene bbox calculations
-        # managed similar to GRAPHICS for garbage collection etc.
         self._selectors: list[BaseSelector] = list()
 
         # legends, managed just like other graphics as explained above
@@ -120,8 +115,6 @@ class PlotArea:
         self._background = pygfx.Background(None, self._background_material)
         self.scene.add(self._background)
 
-        self.set_viewport_rect()
-
     def get_figure(self, obj=None):
         """Get Figure instance that contains this plot area"""
         if obj is None:
@@ -141,11 +134,6 @@ class PlotArea:
         """A parent if relevant"""
         return self._parent
 
-    @property
-    def position(self) -> tuple[int, int] | str:
-        """Position of this plot area within a larger layout (such as a Figure) if relevant"""
-        return self._position
-
     @property
     def scene(self) -> pygfx.Scene:
         """The Scene where Graphics lie in this plot area"""
@@ -284,22 +272,9 @@ class PlotArea:
         """1, 2, or 4 colors, each color must be acceptable by pygfx.Color"""
         self._background_material.set_colors(*colors)
 
-    def get_rect(self) -> tuple[float, float, float, float]:
-        """
-        Returns the viewport rect to define the rectangle
-        occupied by the viewport w.r.t. the Canvas.
-
-        If this is a subplot within a Figure, it returns the rectangle
-        for only this subplot w.r.t. the parent canvas.
-
-        Must return: [x_pos, y_pos, width_viewport, height_viewport]
-
-        """
-        raise NotImplementedError("Must be implemented in subclass")
-
     def map_screen_to_world(
-        self, pos: tuple[float, float] | pygfx.PointerEvent
-    ) -> np.ndarray:
+        self, pos: tuple[float, float] | pygfx.PointerEvent, allow_outside: bool = False
+    ) -> np.ndarray | None:
         """
         Map screen position to world position
 
@@ -312,7 +287,7 @@ class PlotArea:
         if isinstance(pos, pygfx.PointerEvent):
             pos = pos.x, pos.y
 
-        if not self.viewport.is_inside(*pos):
+        if not allow_outside and not self.viewport.is_inside(*pos):
             return None
 
         vs = self.viewport.logical_size
@@ -333,17 +308,14 @@ class PlotArea:
         # default z is zero for now
         return np.array([*pos_world[:2], 0])
 
-    def set_viewport_rect(self, *args):
-        self.viewport.rect = self.get_rect()
-
-    def render(self):
+    def _render(self):
         self._call_animate_functions(self._animate_funcs_pre)
 
         # does not flush, flush must be implemented in user-facing Plot objects
         self.viewport.render(self.scene, self.camera)
 
         for child in self.children:
-            child.render()
+            child._render()
 
         self._call_animate_functions(self._animate_funcs_post)
 
@@ -519,6 +491,10 @@ class PlotArea:
             obj_list = self._graphics
             self._fpl_graphics_scene.add(graphic.world_object)
 
+            # add to tooltip registry
+            if self.get_figure().show_tooltips:
+                self.get_figure().tooltip_manager.register(graphic)
+
         else:
             raise TypeError("graphic must be of type Graphic | BaseSelector | Legend")
 
@@ -532,7 +508,6 @@ class PlotArea:
         if center:
             self.center_graphic(graphic)
 
-        # if we don't use the weakref above, then the object lingers if a plot hook is used!
         graphic._fpl_add_plot_area_hook(self)
 
     def _check_graphic_name_exists(self, name):
@@ -739,7 +714,7 @@ class PlotArea:
         else:
             name = self.name
 
-        return f"{name}: {self.__class__.__name__} @ {hex(id(self))}"
+        return f"{name}: {self.__class__.__name__}"
 
     def __repr__(self):
         newline = "\n\t"
