@@ -195,33 +195,46 @@ class ImageWidget:
         if not self._initialized:
             return
 
-        if not set(index.keys()).issubset(set(self._current_index.keys())):
-            raise KeyError(
-                f"All dimension keys for setting `current_index` must be present in the widget sliders. "
-                f"The dimensions currently used for sliders are: {list(self.current_index.keys())}"
-            )
+        if self._reentrant_block:
+            return
 
-        for k, val in index.items():
-            if not isinstance(val, int):
-                raise TypeError("Indices for all dimensions must be int")
-            if val < 0:
-                raise IndexError("negative indexing is not supported for ImageWidget")
-            if val > self._dims_max_bounds[k]:
-                raise IndexError(
-                    f"index {val} is out of bounds for dimension '{k}' "
-                    f"which has a max bound of: {self._dims_max_bounds[k]}"
+        try:
+            self._reentrant_block = True  # block re-execution until current_index has *fully* completed execution
+            if not set(index.keys()).issubset(set(self._current_index.keys())):
+                raise KeyError(
+                    f"All dimension keys for setting `current_index` must be present in the widget sliders. "
+                    f"The dimensions currently used for sliders are: {list(self.current_index.keys())}"
                 )
 
-        self._current_index.update(index)
+            for k, val in index.items():
+                if not isinstance(val, int):
+                    raise TypeError("Indices for all dimensions must be int")
+                if val < 0:
+                    raise IndexError(
+                        "negative indexing is not supported for ImageWidget"
+                    )
+                if val > self._dims_max_bounds[k]:
+                    raise IndexError(
+                        f"index {val} is out of bounds for dimension '{k}' "
+                        f"which has a max bound of: {self._dims_max_bounds[k]}"
+                    )
 
-        for i, (ig, data) in enumerate(zip(self.managed_graphics, self.data)):
-            frame = self._process_indices(data, self._current_index)
-            frame = self._process_frame_apply(frame, i)
-            ig.data = frame
+            self._current_index.update(index)
 
-        # call any event handlers
-        for handler in self._current_index_changed_handlers:
-            handler(self.current_index)
+            for i, (ig, data) in enumerate(zip(self.managed_graphics, self.data)):
+                frame = self._process_indices(data, self._current_index)
+                frame = self._process_frame_apply(frame, i)
+                ig.data = frame
+
+            # call any event handlers
+            for handler in self._current_index_changed_handlers:
+                handler(self.current_index)
+        except Exception as exc:
+            # raise original exception
+            raise exc  # current_index setter has raised. The lines above below are probably more relevant!
+        finally:
+            # set_value has finished executing, now allow future executions
+            self._reentrant_block = False
 
     @property
     def n_img_dims(self) -> list[int]:
@@ -329,7 +342,7 @@ class ImageWidget:
             manually provide the shape for the Figure, otherwise the number of rows and columns is estimated
 
         figure_kwargs: dict, optional
-            passed to `GridPlot`
+            passed to ``Figure``
 
         names: Optional[str]
             gives names to the subplots
@@ -347,8 +360,6 @@ class ImageWidget:
         """
         self._initialized = False
 
-        self._names = None
-
         if figure_kwargs is None:
             figure_kwargs = dict()
 
@@ -425,7 +436,6 @@ class ImageWidget:
                         raise ValueError(
                             "number of `names` for subplots must be same as the number of data arrays"
                         )
-                    self._names = names
 
             else:
                 raise TypeError(
@@ -496,7 +506,7 @@ class ImageWidget:
                             self._dims_max_bounds[_dim], array.shape[i]
                         )
 
-        figure_kwargs_default = {"controller_ids": "sync"}
+        figure_kwargs_default = {"controller_ids": "sync", "names": names}
 
         # update the default kwargs with any user-specified kwargs
         # user specified kwargs will overwrite the defaults
@@ -518,10 +528,6 @@ class ImageWidget:
 
         self._histogram_widget = histogram_widget
         for data_ix, (d, subplot) in enumerate(zip(self.data, self.figure)):
-            if self._names is not None:
-                name = self._names[data_ix]
-            else:
-                name = None
 
             frame = self._process_indices(d, slice_indices=self._current_index)
             frame = self._process_frame_apply(frame, data_ix)
@@ -554,8 +560,6 @@ class ImageWidget:
                 **graphic_kwargs,
             )
             subplot.add_graphic(ig)
-            subplot.name = name
-            subplot.set_title(name)
 
             if self._histogram_widget:
                 hlut = HistogramLUTTool(data=d, image_graphic=ig, name="histogram_lut")
@@ -583,10 +587,12 @@ class ImageWidget:
 
         self.figure.add_gui(self._image_widget_sliders)
 
-        self._initialized = True
-
         self._current_index_changed_handlers = set()
 
+        self._reentrant_block = False
+
+        self._initialized = True
+
     @property
     def frame_apply(self) -> dict | None:
         return self._frame_apply
@@ -936,8 +942,10 @@ class ImageWidget:
                 # make new graphic first
                 new_graphic = ImageGraphic(data=frame, name="image_widget_managed")
 
-                # set hlut tool to use new graphic
-                subplot.docks["right"]["histogram_lut"].image_graphic = new_graphic
+                if self._histogram_widget:
+                    # set hlut tool to use new graphic
+                    subplot.docks["right"]["histogram_lut"].image_graphic = new_graphic
+
                 # delete old graphic after setting hlut tool to new graphic
                 # this ensures gc
                 subplot.delete_graphic(graphic=subplot["image_widget_managed"])
